close all; clear all;
dpar = struct();

% ********************************************
% Create a FIR filter that approximates the passband behavior of
% the analog filter accurately, and gives a similar stopband rejection
%
% The most straightforward way to model an infinite-impulse-response
% lowpass is to simply sample the impulse response. However, it needs to be
% cut to size (since the FIR filter has only finite length)
% => Chopping it off destroys the out-of-band performance (=rectangular window)
% => use a window function that trades off between passband accuracy and
%    stopband rejection
% => or use the design example below.
% ********************************************
dpar.mStages = 52;
dpar.inRate_Hz = 104e6;

[ffilter_Hz, H] = getExampleLaplaceDomainFilter();

% set the frequency points...
dpar.nominalFreq_Hz = ffilter_Hz;
dpar.nominalComplexGain = H;

dpar.req_stopbandF_Hz = [15e6, 30e6, 55e6];
dpar.req_stopbandMaxGain_dB = [-38, -80, -115];

dpar.req_passbandF_Hz = 9e6;        
dpar.req_passbandEVM_dB = -45;

% offset the impulse response, it is not centered
dpar.delayOffset = 18;

% ********************************************
% Set up filter design object
% ********************************************    
design = YAFIR(dpar);

% ********************************************
% Design the filter
% ********************************************    
% h is the impulse response (FIR tap coefficients).
[h, status] = run(design);
disp(status);    
