close all; clear all;
dpar = struct();

% ********************************************
% an extension of "componentModel1"
% stopband rejection does not matter, but we need
% phase-accurate modeling on a region of the stopband edge
% ********************************************
dpar.mStages = 80;
dpar.inRate_Hz = 104e6;

[ffilter_Hz, H] = getExampleLaplaceDomainFilter();

% set the frequency points...
dpar.nominalFreq_Hz = ffilter_Hz;
dpar.nominalComplexGain = H;

dpar.req_stopbandF_Hz = [ 16e6, 100e6];
dpar.req_stopbandMaxGain_dB = [ -30, -30];
               
dpar.req_passbandF_Hz = 9e6;        
dpar.req_passbandEVM_dB = -45;

% offset the impulse response, it is not centered
dpar.delayOffset = dpar.mStages / 2 - 8;

% ********************************************
% Set up filter design object
% ********************************************    
design = YAFIR(dpar);

% place a passband in the area on the slope that is to be modeled accurately
design = placePassband(...
    design, ...
    'f_Hz', [12e6, 16e6], ...
    'EVM_dB', [-40, -50] - 30); % nominal gain -40..-50 dB, -30 dBc EVM

% ********************************************
% Design the filter
% ********************************************    
% h is the impulse response (FIR tap coefficients).
[h, status] = run(design);
disp(status);    
