close all; clear all;
dpar = struct();

% sampling rate at the input of the filter
dpar.inRate_Hz = 104e6;

% end of passband. A single value will be internally
% expanded to [-9e6, 9e6].
% Asymmetric designs require
% the complexValued = true option.
% This 'default' passband can be omitted entirely, if passbands
% are declared individually later
dpar.req_passbandF_Hz = 9e6;

% defines the maximum allowed ripple in the passband.
dpar.req_passbandRipple_dB = 0.083;

% start of default stopband.
% as with the passband, the default stopband can be omitted,
% if individual bands are placed later.
dpar.req_stopbandF_Hz = 14e6;  
dpar.req_stopbandMaxGain_dB = -30;
dpar.mStages = 52;

% get example filter
[ffilter_Hz, H] = getExampleLaplaceDomainFilter();

% set the frequency points...
dpar.equalizeFreq_Hz = ffilter_Hz;

% ... and the filter response. The design routine will
% use linear interpolation, therefore provide a sufficiently
% dense grid.
% Equalizing an asymmetric response requires
% the complexValued=true option, leading to a complex-valued
% FIR filter.
% The equalization function needs to be normalized.
% Otherwise, pass- and stopband targets will be offset
% by the gain mismatch.
dpar.equalizeComplexGain = H;

% as alternative to the complex gain, a magnitude response
% can be given via an equalizeGain_dB argument.
% dpar.equalizeGain_dB = 20*log10(abs(H));        

% an asymmetric (non-linear-phase) impulse response may
% require a group delay that is not centered in the
% FIR length.
dpar.delayOffset = 2;

% ********************************************
% Set up filter design object
% ********************************************    

design = YAFIR(dpar);
% ********************************************
% Design the filter
% ********************************************    
% h is the impulse response (FIR tap coefficients).
[h, status] = run(design);
disp(status);    
