close all; clear all;
dpar = struct();

% ********************************************
% once the targets are achieved, use the remaining
% 'degrees of freedom' for least-squares optimization.
% The LMS solver will improve, where it is 'cheapest'
% The parameters are not a real-world design
% (0.5 percent EVM => -46 dB)
% ********************************************    
ci = 0;
%ci = 10; % for comparison: force equiripple

% ********************************************
% root-raised cosine upsampling filter for WCDMA transmitter
% The input chip stream arrives at 3.84 Msps, using the
% full bandwidth.
% Before the filter, it is upsampled (zero insertion) to
% 7.68 Msps.
% The filter applies RRC-filtering with 1.22 rolloff.
% ********************************************
% calculate nominal RRC response for lookup table / linear
% interpolation
f_Hz = logspace(1, 8, 10000); f_Hz(1) = -1;
c = abs(f_Hz * 2 / 3.84e6);
c = (c-1)/(0.22); % -1..1 in the transition region
c=min(c, 1);
c=max(c, -1);
RRC_h = sqrt(1/2+cos(pi/2*(c+1))/2);

dpar = struct(...
    'inRate_Hz', 3.84e6, ...
    'fInterp', 2, ...
    'mStages', 45, ...
    'req_passbandF_Hz', 3.84e6 * 1.22 / 2, ...
    'req_passbandEVM_dB', -46, ...
    'req_stopbandF_Hz', 2.46e6, ...
    'req_stopbandMaxGain_dB', -50, ...
    'nominalFreq_Hz', f_Hz, ...
    'nominalGain_dB', 20*log10(RRC_h + 1e-19), ...
    'convergedIterations', ci);

% ********************************************
% Set up filter design object
% ********************************************    
design = YAFIR(dpar);

% ********************************************
% Design a complex-valued filter
% ********************************************    
design = placeStopband(...
    design, ...
    'f_Hz', [-30e6, -16e6], ...
    'g_dB', -50);

design = placePassband(...
    design, ...
    'f_Hz', [-8e6, -2e6], ...
    'EVM_dB', -45);

design = placeStopband(...
    design, ...
    'f_Hz', [3e6, 40e6], ...
    'g_dB', [-30, -50]);

% the frequency response will go berserk, if left completely
% unconstrained => place "soft" stopband everywhere
design = placeStopband(...
    design, ...
    'f_Hz', [-9e9, -16e6], ...
    'g_dB', -10);

% ********************************************
% Design the filter
% ********************************************    
% h is the impulse response (FIR tap coefficients).
[h, status] = run(design);
disp(status);    
